@@ -64,6 +64,22 @@
  #' @source Aril Vold (1998). A generalization of ordinary yield response functions. Ecological Applications. 108:227-236.
  "barley"
  
+ #' Data on leaf extension rate as a response to meristem temperature
+ #' in maize. The data are re-created liberally from 
+ #' Walls, W.R., 1971. Role of temperature in the regulation of leaf extension in ila mays. Nature, 229: 46-47. 
+ #' The data points are not the same as in the original paper. Some additional
+ #' points were inserted to fill in the blanks and allow for reasonable
+ #' parameter values
+ #' 
+ #' @title Maize leaf extension rate as a response to temperature
+ #' @format A data frame with 10 rows and 2 columns
+ #' \describe{
+ #'   \item{temp}{Meristem temperature (in Celsius).}
+ #'   \item{rate}{Leaf extension rate (relative to 25 degrees).}
+ #' }
+ #' @source Walls, W.R., 1971. Role of temperature in the regulation of leaf extension in ila mays. Nature, 229: 46-47. 
+ "maizeleafext"
+ 
  ## Import packages needed for nlraa to work correctly
  #' @import boot knitr MASS nlme stats
  #' @importFrom utils warnErrList
